{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.ActivateAction where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Action
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ControlAction

-- | The act of starting or activating a device or application (e.g. starting a timer or turning on a flashlight).
--
--   [@id@] ActivateAction
--
--   [@label@] Activate Action
--
--   [@comment@] The act of starting or activating a device or application (e.g. starting a timer or turning on a flashlight).
--
--   [@ancestors@] @'Thing','Action','ControlAction'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'ControlAction'@
--
--   [@url@] <http://schema.org/ActivateAction>
data ActivateAction = ActivateAction { actionStatus :: ActionStatus
                                     , agent :: Agent
                                     , endTime :: EndTime
                                     , error :: Error
                                     , instrument :: Instrument
                                     , location :: Location
                                     , object :: Object
                                     , participant :: Participant
                                     , result :: Result
                                     , startTime :: StartTime
                                     , target :: Target
                                     , additionalType :: AdditionalType
                                     , alternateName :: AlternateName
                                     , description :: Description
                                     , image :: Image
                                     , mainEntityOfPage :: MainEntityOfPage
                                     , name :: Name
                                     , potentialAction :: PotentialAction
                                     , sameAs :: SameAs
                                     , url :: Url
                                     }
                      deriving (Show, Read, Eq, Typeable)

instance MetaData ActivateAction where
  _label         = const "Activate Action"
  _comment_plain = const "The act of starting or activating a device or application (e.g. starting a timer or turning on a flashlight)."
  _comment       = const "The act of starting or activating a device or application (e.g. starting a timer or turning on a flashlight)."
  _url           = const "http://schema.org/ActivateAction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ControlAction.ControlAction)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.ControlAction.ControlAction)]