{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.AuthorizeAction where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Action
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.OrganizeAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.AllocateAction

-- | The act of granting permission to an object.
--
--   [@id@] AuthorizeAction
--
--   [@label@] Authorize Action
--
--   [@comment@] The act of granting permission to an object.
--
--   [@ancestors@] @'Thing','Action','OrganizeAction','AllocateAction'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'AllocateAction'@
--
--   [@url@] <http://schema.org/AuthorizeAction>
data AuthorizeAction = AuthorizeAction { recipient :: Recipient
                                       , purpose :: Purpose
                                       , actionStatus :: ActionStatus
                                       , agent :: Agent
                                       , endTime :: EndTime
                                       , error :: Error
                                       , instrument :: Instrument
                                       , location :: Location
                                       , object :: Object
                                       , participant :: Participant
                                       , result :: Result
                                       , startTime :: StartTime
                                       , target :: Target
                                       , additionalType :: AdditionalType
                                       , alternateName :: AlternateName
                                       , description :: Description
                                       , image :: Image
                                       , mainEntityOfPage :: MainEntityOfPage
                                       , name :: Name
                                       , potentialAction :: PotentialAction
                                       , sameAs :: SameAs
                                       , url :: Url
                                       }
                       deriving (Show, Read, Eq, Typeable)

instance MetaData AuthorizeAction where
  _label         = const "Authorize Action"
  _comment_plain = const "The act of granting permission to an object."
  _comment       = const "The act of granting permission to an object."
  _url           = const "http://schema.org/AuthorizeAction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.OrganizeAction.OrganizeAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.AllocateAction.AllocateAction)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.AllocateAction.AllocateAction)]