{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.BreadcrumbList where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ItemList

-- | A BreadcrumbList is an ItemList consisting of a chain of linked Web pages, typically described using at least their URL and their name, and typically ending with the current page.                  The 'position' property is used to reconstruct the order of the items in a BreadcrumbList.      The convention is that a breadcrumb list has an itemListOrder of ItemListOrderAscending (lower values listed first), and that the      first items in this list correspond to the "top" or beginning of the breadcrumb trail, e.g. with a site or section homepage.      The specific values of 'position' are not assigned meaning for a BreadcrumbList, but they should be integers, e.g. beginning      with '1' for the first item in the list.
--
--   [@id@] BreadcrumbList
--
--   [@label@] Breadcrumb List
--
--   [@comment@]       A BreadcrumbList is an ItemList consisting of a chain of linked Web pages, typically described using at least their URL and their name, and typically ending with the current page.      <br/>      <br/>      The 'position' property is used to reconstruct the order of the items in a BreadcrumbList.      The convention is that a breadcrumb list has an itemListOrder of ItemListOrderAscending (lower values listed first), and that the      first items in this list correspond to the "top" or beginning of the breadcrumb trail, e.g. with a site or section homepage.      The specific values of 'position' are not assigned meaning for a BreadcrumbList, but they should be integers, e.g. beginning      with '1' for the first item in the list.      
--
--   [@ancestors@] @'Thing','Intangible','ItemList'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'ItemList'@
--
--   [@url@] <http://schema.org/BreadcrumbList>
data BreadcrumbList = BreadcrumbList { itemListElement :: ItemListElement
                                     , itemListOrder :: ItemListOrder
                                     , numberOfItems :: NumberOfItems
                                     , additionalType :: AdditionalType
                                     , alternateName :: AlternateName
                                     , description :: Description
                                     , image :: Image
                                     , mainEntityOfPage :: MainEntityOfPage
                                     , name :: Name
                                     , potentialAction :: PotentialAction
                                     , sameAs :: SameAs
                                     , url :: Url
                                     }
                      deriving (Show, Read, Eq, Typeable)

instance MetaData BreadcrumbList where
  _label         = const "Breadcrumb List"
  _comment_plain = const "A BreadcrumbList is an ItemList consisting of a chain of linked Web pages, typically described using at least their URL and their name, and typically ending with the current page.                  The 'position' property is used to reconstruct the order of the items in a BreadcrumbList.      The convention is that a breadcrumb list has an itemListOrder of ItemListOrderAscending (lower values listed first), and that the      first items in this list correspond to the "top" or beginning of the breadcrumb trail, e.g. with a site or section homepage.      The specific values of 'position' are not assigned meaning for a BreadcrumbList, but they should be integers, e.g. beginning      with '1' for the first item in the list."
  _comment       = const "      A BreadcrumbList is an ItemList consisting of a chain of linked Web pages, typically described using at least their URL and their name, and typically ending with the current page.      <br/>      <br/>      The 'position' property is used to reconstruct the order of the items in a BreadcrumbList.      The convention is that a breadcrumb list has an itemListOrder of ItemListOrderAscending (lower values listed first), and that the      first items in this list correspond to the "top" or beginning of the breadcrumb trail, e.g. with a site or section homepage.      The specific values of 'position' are not assigned meaning for a BreadcrumbList, but they should be integers, e.g. beginning      with '1' for the first item in the list.      "
  _url           = const "http://schema.org/BreadcrumbList"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ItemList.ItemList)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.ItemList.ItemList)]