{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.BroadcastChannel where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.RadioChannel
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.TelevisionChannel

-- | A unique instance of a BroadcastService on a CableOrSatelliteService lineup.
--
--   [@id@] BroadcastChannel
--
--   [@label@] Broadcast Channel
--
--   [@comment@] A unique instance of a BroadcastService on a CableOrSatelliteService lineup.
--
--   [@ancestors@] @'Thing','Intangible'@
--
--   [@subtypes@] @'RadioChannel','TelevisionChannel'@
--
--   [@supertypes@] @'Intangible'@
--
--   [@url@] <http://schema.org/BroadcastChannel>
data BroadcastChannel = BroadcastChannel { broadcastChannelId :: BroadcastChannelId
                                         , broadcastServiceTier :: BroadcastServiceTier
                                         , inBroadcastLineup :: InBroadcastLineup
                                         , providesBroadcastService :: ProvidesBroadcastService
                                         , additionalType :: AdditionalType
                                         , alternateName :: AlternateName
                                         , description :: Description
                                         , image :: Image
                                         , mainEntityOfPage :: MainEntityOfPage
                                         , name :: Name
                                         , potentialAction :: PotentialAction
                                         , sameAs :: SameAs
                                         , url :: Url
                                         }
                        deriving (Show, Read, Eq, Typeable)

instance MetaData BroadcastChannel where
  _label         = const "Broadcast Channel"
  _comment_plain = const "A unique instance of a BroadcastService on a CableOrSatelliteService lineup."
  _comment       = const "A unique instance of a BroadcastService on a CableOrSatelliteService lineup."
  _url           = const "http://schema.org/BroadcastChannel"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.RadioChannel.RadioChannel)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.TelevisionChannel.TelevisionChannel)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]