{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.BusinessEntityType where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Enumeration

-- | A business entity type is a conceptual entity representing the legal form, the size, the main line of business, the position in the value chain, or any combination thereof, of an organization or business person.    Commonly used values:    http://purl.org/goodrelations/v1#Business     http://purl.org/goodrelations/v1#Enduser     http://purl.org/goodrelations/v1#PublicInstitution     http://purl.org/goodrelations/v1#Reseller
--
--   [@id@] BusinessEntityType
--
--   [@label@] Business Entity Type
--
--   [@comment@] A business entity type is a conceptual entity representing the legal form, the size, the main line of business, the position in the value chain, or any combination thereof, of an organization or business person.<br/>    Commonly used values:<br/><br/>    http://purl.org/goodrelations/v1#Business <br/>    http://purl.org/goodrelations/v1#Enduser <br/>    http://purl.org/goodrelations/v1#PublicInstitution <br/>    http://purl.org/goodrelations/v1#Reseller <br/>        
--
--   [@ancestors@] @'Thing','Intangible','Enumeration'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Enumeration'@
--
--   [@url@] <http://schema.org/BusinessEntityType>
data BusinessEntityType = BusinessEntityType { supersededBy :: SupersededBy
                                             , additionalType :: AdditionalType
                                             , alternateName :: AlternateName
                                             , description :: Description
                                             , image :: Image
                                             , mainEntityOfPage :: MainEntityOfPage
                                             , name :: Name
                                             , potentialAction :: PotentialAction
                                             , sameAs :: SameAs
                                             , url :: Url
                                             }
                          deriving (Show, Read, Eq, Typeable)

instance MetaData BusinessEntityType where
  _label         = const "Business Entity Type"
  _comment_plain = const "A business entity type is a conceptual entity representing the legal form, the size, the main line of business, the position in the value chain, or any combination thereof, of an organization or business person.    Commonly used values:    http://purl.org/goodrelations/v1#Business     http://purl.org/goodrelations/v1#Enduser     http://purl.org/goodrelations/v1#PublicInstitution     http://purl.org/goodrelations/v1#Reseller"
  _comment       = const "A business entity type is a conceptual entity representing the legal form, the size, the main line of business, the position in the value chain, or any combination thereof, of an organization or business person.<br/>    Commonly used values:<br/><br/>    http://purl.org/goodrelations/v1#Business <br/>    http://purl.org/goodrelations/v1#Enduser <br/>    http://purl.org/goodrelations/v1#PublicInstitution <br/>    http://purl.org/goodrelations/v1#Reseller <br/>        "
  _url           = const "http://schema.org/BusinessEntityType"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Enumeration.Enumeration)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Enumeration.Enumeration)]