{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.CheckAction where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Action
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.FindAction

-- | An agent inspects/determines/investigates/inquire or examine an object's accuracy/quality/condition or state.
--
--   [@id@] CheckAction
--
--   [@label@] Check Action
--
--   [@comment@] An agent inspects/determines/investigates/inquire or examine an object's accuracy/quality/condition or state.
--
--   [@ancestors@] @'Thing','Action','FindAction'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'FindAction'@
--
--   [@url@] <http://schema.org/CheckAction>
data CheckAction = CheckAction { actionStatus :: ActionStatus
                               , agent :: Agent
                               , endTime :: EndTime
                               , error :: Error
                               , instrument :: Instrument
                               , location :: Location
                               , object :: Object
                               , participant :: Participant
                               , result :: Result
                               , startTime :: StartTime
                               , target :: Target
                               , additionalType :: AdditionalType
                               , alternateName :: AlternateName
                               , description :: Description
                               , image :: Image
                               , mainEntityOfPage :: MainEntityOfPage
                               , name :: Name
                               , potentialAction :: PotentialAction
                               , sameAs :: SameAs
                               , url :: Url
                               }
                   deriving (Show, Read, Eq, Typeable)

instance MetaData CheckAction where
  _label         = const "Check Action"
  _comment_plain = const "An agent inspects/determines/investigates/inquire or examine an object's accuracy/quality/condition or state."
  _comment       = const "An agent inspects/determines/investigates/inquire or examine an object's accuracy/quality/condition or state."
  _url           = const "http://schema.org/CheckAction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.FindAction.FindAction)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.FindAction.FindAction)]