{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.DefenceEstablishment where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Place
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.CivicStructure
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.GovernmentBuilding

-- | A defence establishment, such as an army or navy base.
--
--   [@id@] DefenceEstablishment
--
--   [@label@] Defence Establishment
--
--   [@comment@] A defence establishment, such as an army or navy base.
--
--   [@ancestors@] @'Thing','Place','CivicStructure','GovernmentBuilding'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'GovernmentBuilding'@
--
--   [@url@] <http://schema.org/DefenceEstablishment>
data DefenceEstablishment = DefenceEstablishment { openingHours :: OpeningHours
                                                 , additionalProperty :: AdditionalProperty
                                                 , address :: Address
                                                 , aggregateRating :: AggregateRating
                                                 , branchCode :: BranchCode
                                                 , containedInPlace :: ContainedInPlace
                                                 , containsPlace :: ContainsPlace
                                                 , event :: Event
                                                 , faxNumber :: FaxNumber
                                                 , geo :: Geo
                                                 , globalLocationNumber :: GlobalLocationNumber
                                                 , hasMap :: HasMap
                                                 , isicV4 :: IsicV4
                                                 , logo :: Logo
                                                 , openingHoursSpecification :: OpeningHoursSpecification
                                                 , photo :: Photo
                                                 , review :: Review
                                                 , telephone :: Telephone
                                                 , additionalType :: AdditionalType
                                                 , alternateName :: AlternateName
                                                 , description :: Description
                                                 , image :: Image
                                                 , mainEntityOfPage :: MainEntityOfPage
                                                 , name :: Name
                                                 , potentialAction :: PotentialAction
                                                 , sameAs :: SameAs
                                                 , url :: Url
                                                 }
                            deriving (Show, Read, Eq, Typeable)

instance MetaData DefenceEstablishment where
  _label         = const "Defence Establishment"
  _comment_plain = const "A defence establishment, such as an army or navy base."
  _comment       = const "A defence establishment, such as an army or navy base."
  _url           = const "http://schema.org/DefenceEstablishment"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Place.Place)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.CivicStructure.CivicStructure)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.GovernmentBuilding.GovernmentBuilding)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.GovernmentBuilding.GovernmentBuilding)]