{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.Demand where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible

-- | A demand entity represents the public, not necessarily binding, not necessarily exclusive, announcement by an organization or person to seek a certain type of goods or services. For describing demand using this type, the very same properties used for Offer apply.
--
--   [@id@] Demand
--
--   [@label@] Demand
--
--   [@comment@] A demand entity represents the public, not necessarily binding, not necessarily exclusive, announcement by an organization or person to seek a certain type of goods or services. For describing demand using this type, the very same properties used for Offer apply.
--
--   [@ancestors@] @'Thing','Intangible'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Intangible'@
--
--   [@url@] <http://schema.org/Demand>
data Demand = Demand { acceptedPaymentMethod :: AcceptedPaymentMethod
                     , advanceBookingRequirement :: AdvanceBookingRequirement
                     , areaServed :: AreaServed
                     , availability :: Availability
                     , availabilityEnds :: AvailabilityEnds
                     , availabilityStarts :: AvailabilityStarts
                     , availableAtOrFrom :: AvailableAtOrFrom
                     , availableDeliveryMethod :: AvailableDeliveryMethod
                     , businessFunction :: BusinessFunction
                     , deliveryLeadTime :: DeliveryLeadTime
                     , eligibleCustomerType :: EligibleCustomerType
                     , eligibleDuration :: EligibleDuration
                     , eligibleQuantity :: EligibleQuantity
                     , eligibleRegion :: EligibleRegion
                     , eligibleTransactionVolume :: EligibleTransactionVolume
                     , gtin12 :: Gtin12
                     , gtin13 :: Gtin13
                     , gtin14 :: Gtin14
                     , gtin8 :: Gtin8
                     , includesObject :: IncludesObject
                     , ineligibleRegion :: IneligibleRegion
                     , inventoryLevel :: InventoryLevel
                     , itemCondition :: ItemCondition
                     , itemOffered :: ItemOffered
                     , mpn :: Mpn
                     , priceSpecification :: PriceSpecification
                     , seller :: Seller
                     , serialNumber :: SerialNumber
                     , sku :: Sku
                     , validFrom :: ValidFrom
                     , validThrough :: ValidThrough
                     , warranty :: Warranty
                     , additionalType :: AdditionalType
                     , alternateName :: AlternateName
                     , description :: Description
                     , image :: Image
                     , mainEntityOfPage :: MainEntityOfPage
                     , name :: Name
                     , potentialAction :: PotentialAction
                     , sameAs :: SameAs
                     , url :: Url
                     }
              deriving (Show, Read, Eq, Typeable)

instance MetaData Demand where
  _label         = const "Demand"
  _comment_plain = const "A demand entity represents the public, not necessarily binding, not necessarily exclusive, announcement by an organization or person to seek a certain type of goods or services. For describing demand using this type, the very same properties used for Offer apply."
  _comment       = const "A demand entity represents the public, not necessarily binding, not necessarily exclusive, announcement by an organization or person to seek a certain type of goods or services. For describing demand using this type, the very same properties used for Offer apply."
  _url           = const "http://schema.org/Demand"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]