{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.DietarySupplement where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalEntity
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalTherapy

-- | A product taken by mouth that contains a dietary ingredient intended to supplement the diet. Dietary ingredients may include vitamins, minerals, herbs or other botanicals, amino acids, and substances such as enzymes, organ tissues, glandulars and metabolites.
--
--   [@id@] DietarySupplement
--
--   [@label@] Dietary Supplement
--
--   [@comment@] A product taken by mouth that contains a dietary ingredient intended to supplement the diet. Dietary ingredients may include vitamins, minerals, herbs or other botanicals, amino acids, and substances such as enzymes, organ tissues, glandulars and metabolites.
--
--   [@ancestors@] @'Thing','MedicalEntity','MedicalTherapy'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'MedicalTherapy'@
--
--   [@url@] <http://schema.org/DietarySupplement>
data DietarySupplement = DietarySupplement { activeIngredient :: ActiveIngredient
                                           , background :: Background
                                           , dosageForm :: DosageForm
                                           , isProprietary :: IsProprietary
                                           , legalStatus :: LegalStatus
                                           , manufacturer :: Manufacturer
                                           , maximumIntake :: MaximumIntake
                                           , mechanismOfAction :: MechanismOfAction
                                           , nonProprietaryName :: NonProprietaryName
                                           , recommendedIntake :: RecommendedIntake
                                           , safetyConsideration :: SafetyConsideration
                                           , targetPopulation :: TargetPopulation
                                           , adverseOutcome :: AdverseOutcome
                                           , contraindication :: Contraindication
                                           , duplicateTherapy :: DuplicateTherapy
                                           , indication :: Indication
                                           , seriousAdverseOutcome :: SeriousAdverseOutcome
                                           , code :: Code
                                           , guideline :: Guideline
                                           , medicineSystem :: MedicineSystem
                                           , recognizingAuthority :: RecognizingAuthority
                                           , relevantSpecialty :: RelevantSpecialty
                                           , study :: Study
                                           , additionalType :: AdditionalType
                                           , alternateName :: AlternateName
                                           , description :: Description
                                           , image :: Image
                                           , mainEntityOfPage :: MainEntityOfPage
                                           , name :: Name
                                           , potentialAction :: PotentialAction
                                           , sameAs :: SameAs
                                           , url :: Url
                                           }
                         deriving (Show, Read, Eq, Typeable)

instance MetaData DietarySupplement where
  _label         = const "Dietary Supplement"
  _comment_plain = const "A product taken by mouth that contains a dietary ingredient intended to supplement the diet. Dietary ingredients may include vitamins, minerals, herbs or other botanicals, amino acids, and substances such as enzymes, organ tissues, glandulars and metabolites."
  _comment       = const "A product taken by mouth that contains a dietary ingredient intended to supplement the diet. Dietary ingredients may include vitamins, minerals, herbs or other botanicals, amino acids, and substances such as enzymes, organ tissues, glandulars and metabolites."
  _url           = const "http://schema.org/DietarySupplement"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEntity.MedicalEntity)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalTherapy.MedicalTherapy)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalTherapy.MedicalTherapy)]