{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.InformAction where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Action
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.InteractAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.CommunicateAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ConfirmAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.RsvpAction

-- | The act of notifying someone of information pertinent to them, with no expectation of a response.
--
--   [@id@] InformAction
--
--   [@label@] Inform Action
--
--   [@comment@] The act of notifying someone of information pertinent to them, with no expectation of a response.
--
--   [@ancestors@] @'Thing','Action','InteractAction','CommunicateAction'@
--
--   [@subtypes@] @'ConfirmAction','RsvpAction'@
--
--   [@supertypes@] @'CommunicateAction'@
--
--   [@url@] <http://schema.org/InformAction>
data InformAction = InformAction { event :: Event
                                 , about :: About
                                 , inLanguage :: InLanguage
                                 , recipient :: Recipient
                                 , actionStatus :: ActionStatus
                                 , agent :: Agent
                                 , endTime :: EndTime
                                 , error :: Error
                                 , instrument :: Instrument
                                 , location :: Location
                                 , object :: Object
                                 , participant :: Participant
                                 , result :: Result
                                 , startTime :: StartTime
                                 , target :: Target
                                 , additionalType :: AdditionalType
                                 , alternateName :: AlternateName
                                 , description :: Description
                                 , image :: Image
                                 , mainEntityOfPage :: MainEntityOfPage
                                 , name :: Name
                                 , potentialAction :: PotentialAction
                                 , sameAs :: SameAs
                                 , url :: Url
                                 }
                    deriving (Show, Read, Eq, Typeable)

instance MetaData InformAction where
  _label         = const "Inform Action"
  _comment_plain = const "The act of notifying someone of information pertinent to them, with no expectation of a response."
  _comment       = const "The act of notifying someone of information pertinent to them, with no expectation of a response."
  _url           = const "http://schema.org/InformAction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.InteractAction.InteractAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.CommunicateAction.CommunicateAction)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.ConfirmAction.ConfirmAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.RsvpAction.RsvpAction)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.CommunicateAction.CommunicateAction)]