{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.PreventionIndication where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalEntity
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalIndication

-- | An indication for preventing an underlying condition, symptom, etc.
--
--   [@id@] PreventionIndication
--
--   [@label@] Prevention Indication
--
--   [@comment@] An indication for preventing an underlying condition, symptom, etc.
--
--   [@ancestors@] @'Thing','MedicalEntity','MedicalIndication'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'MedicalIndication'@
--
--   [@url@] <http://schema.org/PreventionIndication>
data PreventionIndication = PreventionIndication { code :: Code
                                                 , guideline :: Guideline
                                                 , medicineSystem :: MedicineSystem
                                                 , recognizingAuthority :: RecognizingAuthority
                                                 , relevantSpecialty :: RelevantSpecialty
                                                 , study :: Study
                                                 , additionalType :: AdditionalType
                                                 , alternateName :: AlternateName
                                                 , description :: Description
                                                 , image :: Image
                                                 , mainEntityOfPage :: MainEntityOfPage
                                                 , name :: Name
                                                 , potentialAction :: PotentialAction
                                                 , sameAs :: SameAs
                                                 , url :: Url
                                                 }
                            deriving (Show, Read, Eq, Typeable)

instance MetaData PreventionIndication where
  _label         = const "Prevention Indication"
  _comment_plain = const "An indication for preventing an underlying condition, symptom, etc."
  _comment       = const "An indication for preventing an underlying condition, symptom, etc."
  _url           = const "http://schema.org/PreventionIndication"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEntity.MedicalEntity)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalIndication.MedicalIndication)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalIndication.MedicalIndication)]