{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.Property where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible

-- | A property, used to indicate attributes and relationships of some Thing; equivalent to rdf:Property.
--
--   [@id@] Property
--
--   [@label@] Property
--
--   [@comment@] A property, used to indicate attributes and relationships of some Thing; equivalent to rdf:Property.
--
--   [@ancestors@] @'Thing','Intangible'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Intangible'@
--
--   [@url@] <http://schema.org/Property>
data Property = Property { domainIncludes :: DomainIncludes
                         , inverseOf :: InverseOf
                         , rangeIncludes :: RangeIncludes
                         , supersededBy :: SupersededBy
                         , additionalType :: AdditionalType
                         , alternateName :: AlternateName
                         , description :: Description
                         , image :: Image
                         , mainEntityOfPage :: MainEntityOfPage
                         , name :: Name
                         , potentialAction :: PotentialAction
                         , sameAs :: SameAs
                         , url :: Url
                         }
                deriving (Show, Read, Eq, Typeable)

instance MetaData Property where
  _label         = const "Property"
  _comment_plain = const "A property, used to indicate attributes and relationships of some Thing; equivalent to rdf:Property."
  _comment       = const "A property, used to indicate attributes and relationships of some Thing; equivalent to rdf:Property."
  _url           = const "http://schema.org/Property"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]