{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.StructuredValue where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ContactPoint
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.DatedMoneySpecification
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.EngineSpecification
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.GeoCoordinates
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.GeoShape
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.InteractionCounter
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.NutritionInformation
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.OpeningHoursSpecification
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.OwnershipInfo
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.PriceSpecification
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.PropertyValue
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.QuantitativeValue
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.TypeAndQuantityNode
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.WarrantyPromise

-- | Structured values are used when the value of a property has a more complex structure than simply being a textual value or a reference to another thing.
--
--   [@id@] StructuredValue
--
--   [@label@] Structured Value
--
--   [@comment@] Structured values are used when the value of a property has a more complex structure than simply being a textual value or a reference to another thing.
--
--   [@ancestors@] @'Thing','Intangible'@
--
--   [@subtypes@] @'ContactPoint','DatedMoneySpecification','EngineSpecification','GeoCoordinates','GeoShape','InteractionCounter','NutritionInformation','OpeningHoursSpecification','OwnershipInfo','PriceSpecification','PropertyValue','QuantitativeValue','TypeAndQuantityNode','WarrantyPromise'@
--
--   [@supertypes@] @'Intangible'@
--
--   [@url@] <http://schema.org/StructuredValue>
data StructuredValue = StructuredValue { additionalType :: AdditionalType
                                       , alternateName :: AlternateName
                                       , description :: Description
                                       , image :: Image
                                       , mainEntityOfPage :: MainEntityOfPage
                                       , name :: Name
                                       , potentialAction :: PotentialAction
                                       , sameAs :: SameAs
                                       , url :: Url
                                       }
                       deriving (Show, Read, Eq, Typeable)

instance MetaData StructuredValue where
  _label         = const "Structured Value"
  _comment_plain = const "Structured values are used when the value of a property has a more complex structure than simply being a textual value or a reference to another thing."
  _comment       = const "Structured values are used when the value of a property has a more complex structure than simply being a textual value or a reference to another thing."
  _url           = const "http://schema.org/StructuredValue"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.ContactPoint.ContactPoint)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.DatedMoneySpecification.DatedMoneySpecification)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.EngineSpecification.EngineSpecification)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.GeoCoordinates.GeoCoordinates)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.GeoShape.GeoShape)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.InteractionCounter.InteractionCounter)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.NutritionInformation.NutritionInformation)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.OpeningHoursSpecification.OpeningHoursSpecification)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.OwnershipInfo.OwnershipInfo)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.PriceSpecification.PriceSpecification)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.PropertyValue.PropertyValue)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.QuantitativeValue.QuantitativeValue)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.TypeAndQuantityNode.TypeAndQuantityNode)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.WarrantyPromise.WarrantyPromise)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]