{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.Ticket where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible

-- | Used to describe a ticket to an event, a flight, a bus ride, etc.
--
--   [@id@] Ticket
--
--   [@label@] Ticket
--
--   [@comment@] Used to describe a ticket to an event, a flight, a bus ride, etc.
--
--   [@ancestors@] @'Thing','Intangible'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Intangible'@
--
--   [@url@] <http://schema.org/Ticket>
data Ticket = Ticket { dateIssued :: DateIssued
                     , issuedBy :: IssuedBy
                     , priceCurrency :: PriceCurrency
                     , ticketNumber :: TicketNumber
                     , ticketToken :: TicketToken
                     , ticketedSeat :: TicketedSeat
                     , totalPrice :: TotalPrice
                     , underName :: UnderName
                     , additionalType :: AdditionalType
                     , alternateName :: AlternateName
                     , description :: Description
                     , image :: Image
                     , mainEntityOfPage :: MainEntityOfPage
                     , name :: Name
                     , potentialAction :: PotentialAction
                     , sameAs :: SameAs
                     , url :: Url
                     }
              deriving (Show, Read, Eq, Typeable)

instance MetaData Ticket where
  _label         = const "Ticket"
  _comment_plain = const "Used to describe a ticket to an event, a flight, a bus ride, etc."
  _comment       = const "Used to describe a ticket to an event, a flight, a bus ride, etc."
  _url           = const "http://schema.org/Ticket"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]