{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.VoteAction where

--  Valid: 2016-02-03 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Action
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.AssessAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ChooseAction

-- | The act of expressing a preference from a fixed/finite/structured set of choices/options.
--
--   [@id@] VoteAction
--
--   [@label@] Vote Action
--
--   [@comment@] The act of expressing a preference from a fixed/finite/structured set of choices/options.
--
--   [@ancestors@] @'Thing','Action','AssessAction','ChooseAction'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'ChooseAction'@
--
--   [@url@] <http://schema.org/VoteAction>
data VoteAction = VoteAction { candidate :: Candidate
                             , actionOption :: ActionOption
                             , actionStatus :: ActionStatus
                             , agent :: Agent
                             , endTime :: EndTime
                             , error :: Error
                             , instrument :: Instrument
                             , location :: Location
                             , object :: Object
                             , participant :: Participant
                             , result :: Result
                             , startTime :: StartTime
                             , target :: Target
                             , additionalType :: AdditionalType
                             , alternateName :: AlternateName
                             , description :: Description
                             , image :: Image
                             , mainEntityOfPage :: MainEntityOfPage
                             , name :: Name
                             , potentialAction :: PotentialAction
                             , sameAs :: SameAs
                             , url :: Url
                             }
                  deriving (Show, Read, Eq, Typeable)

instance MetaData VoteAction where
  _label         = const "Vote Action"
  _comment_plain = const "The act of expressing a preference from a fixed/finite/structured set of choices/options."
  _comment       = const "The act of expressing a preference from a fixed/finite/structured set of choices/options."
  _url           = const "http://schema.org/VoteAction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.AssessAction.AssessAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ChooseAction.ChooseAction)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.ChooseAction.ChooseAction)]